@@ -21,6 +21,7 @@ impl Icons {
     const DISK_IMAGE: char      = '\u{e271}';  // 
     const DOCKER: char          = '\u{e650}';  // 
     const DOCUMENT: char        = '\u{f1c2}';  // 
+    const DOWNLOAD: char        = '\u{f01da}'; // 󰇚
     const EMACS: char           = '\u{e632}';  // 
     const FILE: char            = '\u{f15b}';  // 
     const FILE_OUTLINE: char    = '\u{f016}';  // 
@@ -59,14 +60,15 @@ impl Icons {
     const LANG_PERL: char       = '\u{e67e}';  // 
     const LANG_PHP: char        = '\u{e73d}';  // 
     const LANG_PYTHON: char     = '\u{e606}';  // 
-    const LANG_R: char          = '\u{f25d}';  // 
+    const LANG_R: char          = '\u{e68a}';  // 
     const LANG_RUBY: char       = '\u{e21e}';  // 
     const LANG_RUBYRAILS: char  = '\u{e73b}';  // 
-    const LANG_RUST: char       = '\u{e7a8}';  // 
+    const LANG_RUST: char       = '\u{e68b}';  // 
     const LANG_SASS: char       = '\u{e603}';  // 
     const LANG_STYLUS: char     = '\u{e600}';  // 
     const LANG_TEX: char        = '\u{e69b}';  // 
     const LANG_TYPESCRIPT: char = '\u{e628}';  // 
+    const LIBRARY: char         = '\u{eb9c}';  // 
     const LICENSE: char         = '\u{f02d}';  // 
     const LOCK: char            = '\u{f023}';  // 
     const MAKE: char            = '\u{e673}';  // 
@@ -85,6 +87,7 @@ impl Icons {
     const PUBLIC_KEY: char      = '\u{f0dd6}'; // 󰷖
     const RAZOR: char           = '\u{f1fa}';  // 
     const REACT: char           = '\u{e7ba}';  // 
+    const README: char          = '\u{f00ba}'; // 󰂺
     const SHEET: char           = '\u{f1c3}';  // 
     const SHELL_CMD: char       = '\u{f489}';  // 
     const SHELL: char           = '\u{f1183}'; // 󱆃
@@ -116,6 +119,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     ".npm"                => Icons::FOLDER_NPM,     // 
     ".ssh"                => Icons::FOLDER_KEY,     // 󰢬
     ".Trash"              => '\u{f1f8}',            // 
+    "Contacts"            => '\u{f024c}',           // 󰉌
     "cron.d"              => Icons::FOLDER_CONFIG,  // 
     "cron.daily"          => Icons::FOLDER_CONFIG,  // 
     "cron.hourly"         => Icons::FOLDER_CONFIG,  // 
@@ -125,7 +129,9 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "Downloads"           => '\u{f024d}',           // 󰉍
     "config"              => Icons::FOLDER_CONFIG,  // 
     "etc"                 => Icons::FOLDER_CONFIG,  // 
+    "Favorites"           => '\u{f069d}',           // 󰚝
     "hidden"              => Icons::FOLDER_HIDDEN,  // 󱞞
+    "home"                => '\u{f10b5}',           // 󱂵
     "include"             => Icons::FOLDER_CONFIG,  // 
     "Mail"                => '\u{f01f0}',           // 󰇰
     "Movies"              => '\u{f0fce}',           // 󰿎
@@ -173,7 +179,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".npmrc"              => Icons::NPM,            // 
     ".profile"            => Icons::SHELL,          // 󱆃
     ".python_history"     => Icons::LANG_PYTHON,    // 
-    ".rustfmt.toml"       => Icons::LANG_RUST,      // 
+    ".rustfmt.toml"       => Icons::LANG_RUST,      // 
     ".rvm"                => Icons::LANG_RUBY,      // 
     ".rvmrc"              => Icons::LANG_RUBY,      // 
     ".tcshrc"             => Icons::SHELL,          // 󱆃
@@ -196,8 +202,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "bashrc"              => Icons::SHELL,          // 󱆃
     "bspwmrc"             => Icons::CONFIG,         // 
     "build.gradle.kts"    => Icons::GRADLE,         // 
-    "Cargo.lock"          => Icons::LANG_RUST,      // 
-    "Cargo.toml"          => Icons::LANG_RUST,      // 
+    "Cargo.lock"          => Icons::LANG_RUST,      // 
+    "Cargo.toml"          => Icons::LANG_RUST,      // 
     "CMakeLists.txt"      => Icons::MAKE,           // 
     "composer.json"       => Icons::LANG_PHP,       // 
     "composer.lock"       => Icons::LANG_PHP,       // 
@@ -272,7 +278,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "profile"             => Icons::SHELL,          // 󱆃
     "pyproject.toml"      => Icons::LANG_PYTHON,    // 
     "Rakefile"            => Icons::LANG_RUBY,      // 
-    "release.toml"        => Icons::LANG_RUST,      // 
+    "README"              => Icons::README,         // 󰂺
+    "release.toml"        => Icons::LANG_RUST,      // 
     "requirements.txt"    => Icons::LANG_PYTHON,    // 
     "robots.txt"          => '\u{f06a9}',           // 󰚩
     "rubydoc"             => Icons::LANG_RUBYRAILS, // 
@@ -318,6 +325,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "bash"           => Icons::SHELL_CMD,        // 
     "bat"            => Icons::OS_WINDOWS_CMD,   // 
     "bats"           => Icons::SHELL_CMD,        // 
+    "bdf"            => Icons::FONT,             // 
     "bib"            => Icons::LANG_TEX,         // 
     "bin"            => Icons::BINARY,           // 
     "bmp"            => Icons::IMAGE,            // 
@@ -370,12 +378,12 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "diff"           => Icons::DIFF,             // 
     "djv"            => Icons::DOCUMENT,         // 
     "djvu"           => Icons::DOCUMENT,         // 
-    "dll"            => Icons::OS_WINDOWS,       // 
+    "dll"            => Icons::LIBRARY,          // 
     "dmg"            => Icons::DISK_IMAGE,       // 
     "doc"            => Icons::DOCUMENT,         // 
     "docx"           => Icons::DOCUMENT,         // 
     "dot"            => '\u{f1049}',             // 󱁉
-    "download"       => '\u{f01da}',             // 󰇚
+    "download"       => Icons::DOWNLOAD,         // 󰇚
     "drawio"         => '\u{ebba}',              // 
     "dump"           => Icons::DATABASE,         // 
     "dvi"            => Icons::IMAGE,            // 
@@ -397,6 +405,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ex"             => Icons::LANG_ELIXIR,      // 
     "exe"            => Icons::OS_WINDOWS_CMD,   // 
     "exs"            => Icons::LANG_ELIXIR,      // 
+    "fdmdownload"    => Icons::DOWNLOAD,         // 󰇚
     "fish"           => Icons::SHELL_CMD,        // 
     "flac"           => Icons::AUDIO,            // 
     "flv"            => Icons::VIDEO,            // 
@@ -475,6 +484,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "lhs"            => Icons::LANG_HASKELL,     // 
     "license"        => Icons::LICENSE,          // 
     "lisp"           => '\u{f0172}',             // 󰅲
+    "lib"            => Icons::LIBRARY,          // 
     "localized"      => Icons::OS_APPLE,         // 
     "lock"           => Icons::LOCK,             // 
     "log"            => '\u{f18d}',              // 
@@ -561,6 +571,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "psd"            => '\u{e7b8}',              // 
     "psd1"           => Icons::POWERSHELL,       // 
     "psm1"           => Icons::POWERSHELL,       // 
+    "psf"            => Icons::FONT,             // 
     "pub"            => Icons::PUBLIC_KEY,       // 󰷖
     "pxm"            => Icons::IMAGE,            // 
     "py"             => Icons::LANG_PYTHON,      // 
@@ -570,21 +581,21 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "pyo"            => Icons::LANG_PYTHON,      // 
     "qcow"           => Icons::DISK_IMAGE,       // 
     "qcow2"          => Icons::DISK_IMAGE,       // 
-    "r"              => Icons::LANG_R,           // 
+    "r"              => Icons::LANG_R,           // 
     "rar"            => Icons::COMPRESSED,       // 
     "raw"            => Icons::IMAGE,            // 
     "razor"          => Icons::RAZOR,            // 
     "rb"             => Icons::LANG_RUBY,        // 
-    "rdata"          => Icons::LANG_R,           // 
+    "rdata"          => Icons::LANG_R,           // 
     "rdb"            => '\u{e76d}',              // 
     "rdoc"           => Icons::MARKDOWN,         // 
-    "rds"            => Icons::LANG_R,           // 
-    "readme"         => Icons::MARKDOWN,         // 
-    "rlib"           => Icons::LANG_RUST,        // 
-    "rmd"            => Icons::MARKDOWN,         // 
-    "rmeta"          => Icons::LANG_RUST,        // 
+    "rds"            => Icons::LANG_R,           // 
+    "readme"         => Icons::README,           // 󰂺
+    "rlib"           => Icons::LANG_RUST,        // 
+    "rmd"            => Icons::MARKDOWN,         // 
+    "rmeta"          => Icons::LANG_RUST,        // 
     "rpm"            => '\u{e7bb}',              // 
-    "rs"             => Icons::LANG_RUST,        // 
+    "rs"             => Icons::LANG_RUST,        // 
     "rspec"          => Icons::LANG_RUBY,        // 
     "rspec_parallel" => Icons::LANG_RUBY,        // 
     "rspec_status"   => Icons::LANG_RUBY,        // 
